package be.ac.ua.cloudexchange;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import com.csvreader.CsvReader;

/**
 * Class that uses java CSV reader to read in the data from the CSV file
 * downloaded from the cloudexchange.org website
 * 
 * @see http://sourceforge.net/projects/javacsv/
 * @author Vermeersch Kurt
 * @date October 2010
 */
public class CSVHandler {

	/** CSVReader instance */
	private CsvReader fReader;

	/** List of list in which the contents of the CSV file are read */
	protected List<List<String>> fContents = new ArrayList<List<String>>();

	/**
	 * Constructor for CSVHandler
	 * 
	 * @param inputFile
	 *            CSV file to read
	 */
	public CSVHandler(final String inputFile) {
		try {
			fReader = new CsvReader(inputFile);
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		}
	}

	/**
	 * Parse the CSV file and store its contents
	 */
	public void parse() {
		try {
			if (fReader != null) {
				fContents = new ArrayList<List<String>>();
				while (fReader.readRecord()) {
					int cols = fReader.getColumnCount();
					List<String> content = new ArrayList<String>();
					for (int i = 0; i < cols; i++) {
						content.add(fReader.get(i));
					}
					fContents.add(content);
				}
			}
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

}
