package be.ac.ua.cloudexchange;


import java.io.File;
import java.io.IOException;
import java.util.List;

import org.jfree.chart.ChartFactory;
import org.jfree.chart.ChartUtilities;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.axis.NumberAxis;
import org.jfree.chart.axis.NumberTickUnit;
import org.jfree.chart.axis.ValueAxis;
import org.jfree.chart.plot.PlotOrientation;
import org.jfree.data.xy.XYDataset;
import org.jfree.data.xy.XYSeriesCollection;

/**
 * Class that uses JFreeChart to create an appropriate chart
 * 
 * @see http://www.jfree.org/jfreechart/
 * @author Vermeersch Kurt
 * @date October 2010
 */
public class ChartGenerator {
	
	/**
	 * Create an XY Step Chart
	 * 
	 * @param fileName name of the output file
	 * @param series series of points to plot
	 */
	public static void createXYChart(final String fileName,List<CSVDataSeries> series){
		XYSeriesCollection xySeriesCollection = new XYSeriesCollection();
		for (CSVDataSeries xySeries : series) {
			xySeriesCollection.addSeries(xySeries.toXYSeries());
		}
		XYDataset xyDataset=xySeriesCollection;
		JFreeChart chart = ChartFactory.createXYStepChart
		                     ("Average spot price over time",//Title
		                      "Time",         //X-Axis label
		                      "Avg Price",         //Y-Axis label
		                      xyDataset,        //Dataset
		                      PlotOrientation.VERTICAL, 			//PlotOrientation
		                      true,             //Legend
		                      false, 			//Tooltips
		                      false				//Urls
		                     );
		ValueAxis axis = chart.getXYPlot().getRangeAxis();
		((NumberAxis) axis).setTickUnit(new NumberTickUnit(0.1));
		try {
			ChartUtilities.saveChartAsJPEG(new File(fileName+".jpg"), chart, 600, 200);
		} catch (IOException e) {
			e.printStackTrace();
		}

	}
	

}
