package be.ac.ua.cloudexchange;

import java.util.List;

/**
 * Main class for an application that transform the CSV file from
 * cloudexchange.org to a graph containing the average prices of each day.
 * 
 * @author Vermeersch Kurt
 * @date October 2010
 */
public class Main {

	/**
	 * Main function
	 * 
	 * @param args
	 *            the program arguments
	 */
	public static void main(String[] args) {
		//Handle program arguments
		if (args.length != 1) {
			System.err.println("usage Main <input CSV file>");
			System.exit(0);
		}
		final String inputFile = args[0];
		//Create average spot price graph
		System.out.println("Parsing input file [" + inputFile + "]");
		final SpotAvgCSVHandler handler = new SpotAvgCSVHandler(inputFile);
		handler.parse();
		System.out.println("Calculating average spot price of each day");
		final List<CSVDataSeries> series = handler.takeAvg();
		System.out.println("Creating average spot price graph [" + inputFile
				+ ".jpg]");
		ChartGenerator.createXYChart(inputFile, series);
		//Create average spot price per day/night graph
		System.out.println("Parsing input file [" + inputFile + "]");
		final SpotAvgDayNightCSVHandler handlerDN = new SpotAvgDayNightCSVHandler(inputFile);
		handlerDN.parse();
		System.out.println("Calculating average spot price for each day/night");
		final List<CSVDataSeries> seriesDN = handlerDN.takeAvg();
		System.out.println("Creating average spot price per day/night graph [" + inputFile
				+ "DN.jpg]");
		ChartGenerator.createXYChart(inputFile+"DN", seriesDN);
		System.out.println("Terminated.");
	}

}
