package be.ac.ua.cloudexchange;

/**
 * Class representing a generic Pair type
 * 
 * @author Vermeersch Kurt
 * @date October 2010
 */
public class Pair<T, U> {

	/** First element of the pair */
	private final T first;
	/** Second element of the pair */
	private final U second;
	/** Hash of the pair */
	private transient final int hash;

	/**
	 * Constructor for Pair
	 * 
	 * @param f
	 *            first element
	 * @param s
	 *            second element
	 */
	public Pair(T f, U s) {
		this.first = f;
		this.second = s;
		hash = (first == null ? 0 : first.hashCode() * 31)
				+ (second == null ? 0 : second.hashCode());
	}

	/**
	 * @return the first element of the pair
	 */
	public T getFirst() {
		return first;
	}

	/**
	 * @return the second element of the pair
	 */
	public U getSecond() {
		return second;
	}

	@Override
	public int hashCode() {
		return hash;
	}

	@SuppressWarnings("unchecked")
	@Override
	public boolean equals(Object oth) {
		if (this == oth) {
			return true;
		}
		if (oth == null || !(getClass().isInstance(oth))) {
			return false;
		}
		Pair<T, U> other = (Pair<T, U>) oth;
		return (first == null ? other.first == null : first.equals(other.first))
				&& (second == null ? other.second == null : second
						.equals(other.second));
	}

}