package be.ac.ua.cloudexchange;

import java.util.ArrayList;
import java.util.List;

import org.jfree.date.DateUtilities;

/**
 * Class that extends the CSVHandler and that is used to calculate the average spot prices
 * for all the different days
 * 
 * @author Vermeersch Kurt
 * @date October 2010
 */
public class SpotAvgCSVHandler extends CSVHandler{

	/**
	 * Constructor for SpotAvgCSVHandler
	 * 
	 * @param inputFile
	 *            CSV file to read
	 */
	public SpotAvgCSVHandler(final String inputFile) {
		super(inputFile);
	}

	/**
	 * Calculate the average spot price for each day
	 * 
	 * @return list containing data series of pairs of dates and the corresponding calculated average spot price
	 */
	public List<CSVDataSeries> takeAvg() {
		List<CSVDataSeries> series = new ArrayList<CSVDataSeries>();
		final CSVDataSeries serie = new CSVDataSeries("Avg Prices Evolution");
		String date="";
		double sum=0;
		int count=0;
		for (int i = 0; i < fContents.size(); i++) {
			List<String> record = fContents.get(i);
			String dateStr = record.get(0);
			String priceStr = record.get(1);
			double price=Double.parseDouble(priceStr);
			String[] splitted = dateStr.split(" ");
			String d=splitted[0];
			if(d.equals(date)){
				sum+=price;
				count++;
			} else if (date.equals("")) {
				date=d;
				sum=price;
				count=1;
			} else {
				String[] splittedDate = date.split("/");
				serie.add(
						DateUtilities.createDate(Integer.parseInt(splittedDate[2]),
								Integer.parseInt(splittedDate[0]),
								Integer.parseInt(splittedDate[1])).getTime(),
								sum/count);
				date=d;
				sum=price;
				count=1;
			}
			if(i==fContents.size()-1){
				String[] splittedDate = d.split("/");
				serie.add(
						DateUtilities.createDate(Integer.parseInt(splittedDate[2]),
								Integer.parseInt(splittedDate[0]),
								Integer.parseInt(splittedDate[1])).getTime(),
								sum/count);
			}
		}
		series.add(serie);
		return series;
	}
	
}