package be.ac.ua.cloudexchange;

import java.util.ArrayList;
import java.util.List;

import org.jfree.date.DateUtilities;

/**
 * Class that extends the CSVHandler and that is used to calculate the average
 * spot prices for all the different day and nights
 * 
 * @author Vermeersch Kurt
 * @date October 2010
 */
public class SpotAvgDayNightCSVHandler extends CSVHandler {

	/** Start hour of the night */
	public static int NIGHT_START = 0;
	/** End hour of the night */
	public static int NIGHT_END = 8;

	/**
	 * Constructor for SpotAvgDayNightCSVHandler
	 * 
	 * @param inputFile
	 *            CSV file to read
	 */
	public SpotAvgDayNightCSVHandler(final String inputFile) {
		super(inputFile);
	}

	/**
	 * Calculate the average spot price for each day/night
	 * 
	 * @return list containing data series of pairs of dates and the
	 *         corresponding calculated average spot price
	 */
	public List<CSVDataSeries> takeAvg() {
		List<CSVDataSeries> series = new ArrayList<CSVDataSeries>();
		final CSVDataSeries serieD = new CSVDataSeries(
				"Avg Prices Evolution Day");
		final CSVDataSeries serieN = new CSVDataSeries(
				"Avg Prices Evolution Night");
		String date = "";
		double sumD = 0, sumN = 0;
		int countD = 0, countN = 0;
		for (int i = 0; i < fContents.size(); i++) {
			List<String> record = fContents.get(i);
			String dateStr = record.get(0);
			String priceStr = record.get(1);
			double price = Double.parseDouble(priceStr);
			String[] splitted = dateStr.split(" ");
			String[] timeSplit = splitted[1].split(":");
			int timeHour = Integer.parseInt(timeSplit[0]);
			boolean isNight = false;
			if (timeHour < NIGHT_END && timeHour >= NIGHT_START) {
				isNight = true;
			}
			String d = splitted[0];
			if (d.equals(date)) {
				if (isNight) {
					sumN += price;
					//System.out.println(d+"-"+splitted[1]+" n="+price);
					countN++;
				} else {
					sumD += price;
					countD++;
				}
			} else if (date.equals("")) {
				date = d;
				if (isNight) {
					sumN = price;
					countN = 1;
					//System.out.println(d+"-"+splitted[1]+" n="+price);
				} else {
					sumD = price;
					countD = 1;
				}
			} else {
				String[] splittedDate = date.split("/");
				serieN.add(DateUtilities.createDate(
						Integer.parseInt(splittedDate[2]),
						Integer.parseInt(splittedDate[0]),
						Integer.parseInt(splittedDate[1])).getTime(), sumN
						/ countN);
				//System.out.println("Night: " + date + " " + sumN +"/"+countN+"="+sumN/countN);
				serieD.add(DateUtilities.createDate(
						Integer.parseInt(splittedDate[2]),
						Integer.parseInt(splittedDate[0]),
						Integer.parseInt(splittedDate[1])).getTime(), sumD
						/ countD);
				//System.out.println("Day: " + date + " " + sumD +"/"+countD+"="+sumD/countD);
				date = d;
				if (isNight) {
					sumN = price;
					//System.out.println(d+"-"+splitted[1]+" n="+price);
					countN = 1;
					sumD = 0;
					countD = 0;
				} else {
					sumN = 0;
					countN = 0;
					sumD = price;
					countD = 1;
				}
			}
			if (i == fContents.size() - 1) {
				String[] splittedDate = d.split("/");
				serieN.add(DateUtilities.createDate(
						Integer.parseInt(splittedDate[2]),
						Integer.parseInt(splittedDate[0]),
						Integer.parseInt(splittedDate[1])).getTime(), sumN
						/ countN);
				//System.out.println("#Night: " + d + " " + sumN / countN);
				serieD.add(DateUtilities.createDate(
						Integer.parseInt(splittedDate[2]),
						Integer.parseInt(splittedDate[0]),
						Integer.parseInt(splittedDate[1])).getTime(), sumD
						/ countD);
				//System.out.println("#Day: " + d + " " + sumD / countD);
			}
		}
		series.add(serieD);
		series.add(serieN);
		return series;
	}

}